#pragma once

#include <stddef.h>
#include <stdint.h>

class imm_clearvoice
{
public:



    /// @brief Constructor for the Immersitech ClearVoice object.
	///
	/// @param[in] license_file_name The path to your immersitech license file including the file name ("/path/my_license.dat").
	/// @param[in] sampling_rate The input sampling rate of the new participant (must be an integer divisible by 100).
    /// @param[in] enable_auto_eq Whether automatic EQ is enabled or not.
    /// @param[in] enable_agc Whether automatic gain control is enabled or not.
    /// @param[in] anc_mix The wet/dry mix of the automatic noise cancellation. (0-100. 100 is only clean output, while 0 is only noisy)
	/// @return An Immersitech Clear Voice object of your initialized library. This object will be used for the other functions in the Immersitech API
	imm_clearvoice(const char* license_filepath, int sampling_rate, bool enable_auto_eq, bool enable_agc, float anc_mix);

	/// @brief Constructor for the Immersitech ClearVoice object.
	///
	/// @param[in] license_file_data The pointer to the in-memory license file data.
    /// @param[in] license_file_data_size The size of your in-memory license file data.
	/// @param[in] sampling_rate The input sampling rate of the new participant (must be an integer divisible by 100).
    /// @param[in] enable_auto_eq Whether automatic EQ is enabled or not.
    /// @param[in] enable_agc Whether automatic gain control is enabled or not.
    /// @param[in] anc_mix The wet/dry mix of the automatic noise cancellation. (0-100. 100 is only clean output, while 0 is only noisy)
	/// @return An Immersitech Clear Voice object of your initialized library. This object will be used for the other functions in the Immersitech API
	imm_clearvoice(uint8_t* license_file_data, size_t license_file_data_size, int sampling_rate, bool enable_auto_eq, bool enable_agc, float anc_mix);

	/// @brief Destructor for the Immersitech ClearVoice object.
	~imm_clearvoice();

	/// @brief Process a single channel 10ms audio block and return VAD flag
    ///
    /// @param[in] input The pointer to your input buffer
    /// @param[out] output The pointer to your output buffer
	/// @return float value 0.0-1.0 representing the likelihood that speech is present in the output buffer
	float process(float* input, float* output);


	/// @brief Set output mixture level (0 - 100) between noisy input and clean output
    ///
    /// @param[in] val float value 0-100
	void set_anc_mix(float val);

    /// @brief Get output mixture level between noisy input and clean output
    ///
    /// @return float value 0-100
	float get_anc_mix(void);

	/// @brief Enable or disable automatic equalization
    ///
    /// @param[in] val True for enable, False for disable
	void set_auto_eq(bool val);

    /// @brief Get automatic equalization setting
    ///
	/// @return bool value true or false
	bool get_auto_eq(void);

	/// @brief Enable or disable automatic gain control
    ///
    /// @param[in] val True for enable, False for disable
	void set_agc(bool val);

    /// @brief Get automatic gain control setting
    ///
	/// @return bool value true or false
	bool get_agc(void);


private:
	void* m_clearvoice;
};
